/*
 * FileIterator.java
 *
 * Created on 31 December 2005, 11:10
 *
 */

package blbutil;

/**
 *
 * @author Brian L Browning
 */

/**
 * An iterator for data in a textfile.  If an IOExceptions is thrown while
 * reading a file, the IOException is trapped, an appropriate error message
 * is written to standard out, and the Java Virtual Machine is
 * terminated.  The <code>remove</code> method is unsupported and throws an
 * <code>UnsupportedOperationException</code>.  
 * <p/>
 * 
 * When the file iterator is no
 * longer needed the <code>close</code> method should be invoked to free up
 * system resources.  After calling <code>close</code>, invoking 
 * <code>hasNext</code> returns <code>false</code>, and invoking
 * <code>next</code> will throw a <code>NoSuchElementException</code>.
 */
public interface FileIterator<E> extends java.util.Iterator<E> {

    /**
     * Closes the file input stream.  After invoking
     * <code>close</code>, further invocations of
     * <code>close</code> have no effect.
     */
    public void close();

    /**
     * Returns a summary of the
     * <code>LineIterator</code> object.  The exact details of the
     * summary are unspecified and subject to change.
     *
     * @return a summary of the LineIterator object.
     */
    public String toString();
}
