/*
 * Validator.java
 *
 * Created on 31 May 2006, 08:36
 *
 */

package blbutil.validator;

/**
 * @author Brian L Browning
 */

import java.util.Map;

/**
 * Class <code>Validator</code> is used to validate a map entry.
 */
public interface Validator {
    
    /**
     * Validates the map entry for the key <code>this.key()</code>
     * in the specified map.  If
     * <code>!map.containsKey(this.key()) && !this.isRequired()</code> 
     * then the entry <code>(this.key(), this.devaultValue)</code> will
     * be added to the map.
     *
     * @param a map whose entry for the key <code>this.key()</code>
     * is to be validated.
     *
     * @throws IllegalArgumentException if 
     * <code>!map.containsKey(this.key()) && this.isRequired()</code> 
     * or if map entry corresponding to the key <code>this.key()</code> 
     * does not validate.
     */
    public void validate(Map<String, String> map);
    
    /**
     * Returns the key in the (key, value) pair that
     * is validated by <code>this</code>.  
     *
     * @return the key in the (key, value) pair that
     * is validated by <code>this</code>.
     */
    public String key();
    
    /**
     * Returns the default value for the key <code>this.key()</code>.  
     * the empty string ("") is returned if there is no default value.
     *
     * @return the default value for the key <code>this.key()</code>.  
     * the empty string ("") is returned if there is no default value.
     */
    public String defaultValue();
    
    /**
     * Returns <code>true</code> if <code>this.key()</code> is required to
     * be present in a map and be mapped to a non-null, non-empty value in
     * order for the map to validate in the <code>validate</code> method, 
     * and returns <code>false</code> otherwise.
     *
     * @return <code>true</code> if <code>this.key()</code> is required to
     * be present in a map and be mapped to a non-null, non-empty string in
     * order for the map to validate in the <code>validate</code> method, 
     * and returns <code>false</code> otherwise.
     */
    public boolean isRequired();
    
    /**
     * Returns <code>true</code> if the <code>this.key()</code> map entry is
     * an advanced option and <code>false</code> otherwise.
     *
     * @return <code>true</code> if the <code>this.key()</code> map entry is
     * an advanced option and <code>false</code> otherwise.
     */
    public boolean isAdvanced();
    
    /**
     * Returns a string representation of <code>this</code>.  The exact
     * details of the representation are unspecified and subject to change.
     *
     * @return a string representation of <code>this</code>.  The exact
     * details of the representation are unspecified and subject to change.
     */
    public String toString();
    
}
