/*
 * MarkerLineInterface.java
 *
 * Created on 22 June 2006, 13:30
 */

package permtester;

/**
 * @author Brian L Browning
 */

/*
 * Interface <code>MarkerLineInterface</code> represents genetic marker
 * data.
 */
public interface MarkerLineInterface {
    
    /**
     * Returns <code>true</code> if missing alleles are coded as 0 
     * and returns <code>false</code> if there is no missing allele code.
     * 
     * @return <code>true</code> if missing alleles are coded as 0 
     * and returns <code>false</code> if there is no missing allele code.
     */
    public boolean hasMissingCode();
    
    /**
     * Returns the <code>String</code> coded as the specified integer.
     * 
     * @param j an integer coding for an allele.
     * @return the <code>String</code> coded as the specified integer.
     * @throws IndexOutOfBoundsException if 
     * <code>j < 0 || j &ge; this.nAlleleCodes()</code>.
     */
    public String allele(int j);

    /**
     * Returns the number of distinct alleles(including the missing allele
     * if <code>this.hasMissingCoding()==true</code>) for the marker 
     * represented by <code>this</code>.
     * 
     * @return the number of distinct alleles (including the missing allele
     * if <code>this.hasMissingCoding()==true</code>) for the marker 
     * represented by <code>this</code>.
     */
    public int nAlleleCodes();

    /**
     * Returns <code>this.data().length</code>, the number of 
     * alleles (including missing alleles) in the marker data 
     * represented by <code>this</code>.
     *
     * @return <code>this.data().length</code>, the number of
     * alleles (including missing alleles) in the marker 
     * data represented by <code>this</code>.
     */
    public int nAlleles();
    
    /**
     * Return the an integer array containing the 
     * white-space delimited, integer-coded data for the marker
     * represented by <code>this</code>.
     * 
     * @return an <code>int</code> array containing the 
     * white-space delimited, integer-coded data for a marker
     * represented by <code>this</code>.
     */
    public int[] data();

    /**
     * Return the <code>String</code> identifier for the marker
     * represented by <code>this</code>.
     * 
     * @return the <code>String</code> identifier for the marker
     * represented by <code>this</code>.
     */
    public String identifier();

    /**
     * Returns a string representation of <code>this</code>.
     * The format of this representation is not specified and subject
     * to change.
     * 
     * @return a string representation of <code>this</code>.
     */
    public String toString();
    
}
