/*
 * Test.java
 *
 * Created on 16 May 2006, 19:17
 *
 */

package permtester;

/**
 * @author Brian L Browning
 */

/**
 * Class <code>Test</code> is used to test for association between
 * a diallelic marker and a binary trait.
 */
public interface Test {
    
    /**
     * Returns an array of p-values from tests of association of 
     * the specified marker and the specified trait using allele 
     * counts and case allele counts specified at object construction.
     *
     * @param trait a boolean array giving trait status for each allele.
     * @param marker a diallelic marker.
     *
     * @return an array of p-values from tests of association of 
     * the specified marker and the specified trait.
     *
     * @throws IllegalArgumentException if 
     * <code>trait.length != marker.alleleCount()</code>.
     */
    public double[] pValues(boolean[] trait, Diallelic marker); 
    
    /**
     * Returns an array of p-values from tests of association of 
     * the specified marker and the specified trait.  The contract 
     * for this method is undefined if the specified allele counts
     * and case allele counts in each strata are inconsistent 
     * with the specified trait and marker.
     *
     * @param trait a boolean array giving trait status for each allele.
     * @param marker a diallelic marker.
     * @param caseAlleleCount an array whose j-th entry is the number of 
     * case alleles in the j-th stratum.
     * @param alleleCount an array whose j-th entry is the number of alleles
     * in the j-th stratum.
     *
     * @return an array of p-values from tests of association of 
     * the specified marker and the specified trait.
     *
     * @throws IllegalArgumentException if 
     * <code>trait.length != marker.alleleCount()</code>.
     */    
    public double[] pValues(boolean[] trait, Diallelic marker, 
            int[] caseAlleleCount, int[] alleleCount);

    
    /**
     * Returns a string array whose length equals the length of the array 
     * returned by <code>pValues</code> and whose entries describe 
     * the p-values returned by <code>pValues</code>.
     *
     * @return a string array whose length equals the length of the array 
     * returned by <code>pValues</code> and whose entries describe 
     * the p-values returned by <code>pValues</code>.
     */
    public String[] tests();
    
    /**
     * Returns a description of <code>this</code>.  The exact description
     * is unspecified and subject to change.
     *
     * @return a description of <code>this</code>.  The exact description
     * is unspecified and subject to change.
     */
    public String toString();
    
}
